Post
Switching to a custom ViewGroup implementation brought the offending measurement pass from ~400ms down to ~7ms; github.com/moreSwift/sw...
github.comAndroidBackend: Switch to custom container (RelativeLayout too slow) by stackotter · Pull Request #550 · moreSwift/swift-cross-uiRelativeLayout's onMeasure implementation has a branching factor of 2, leading to Android's measurement pass being exponential with regard to the depth of the SwiftCrossUI view hierarchy. T...
0 reposts2 likes
No replies yet.